import { Card, Modal, Typography, Upload } from 'antd';
import 'antd/dist/antd.css';
import React from 'react';

interface ModalProps {
    onCancel: () => void;
    documentName: string;
    content: string;
}

/**
 * Creates a modal window that loads documents to the app.
 * @returns The modal window.
 */
const DocPreviewModal: React.FC<ModalProps> = ({ onCancel, documentName, content }) => {
    /**
     * Handles successful closing of the modal window.
     */
    const handleOk = () => {
        onCancel();
    };

    /**
     * Handles cancelling of the model window.
     */
    const handleCancel = () => {
        onCancel();
    };

    return (
        <Modal
            title={<Typography.Title level={3}>{documentName}</Typography.Title>}
            // title={documentName}
            onOk={handleOk}
            visible={true}
            onCancel={handleCancel}
            footer={null}
            width={1200}
            maskClosable={false}
        >
            <Card style={{ overflowY: 'auto', maxHeight: '70vh' }}>
                <div dangerouslySetInnerHTML={{ __html: content ?? '' }} />
            </Card>
        </Modal>
    );
};

export default DocPreviewModal;
